# iceflow

```{toctree}
:maxdepth: 2
:hidden:
:caption: content

getting-started.md
iceflow-example.ipynb
iceflow-with-icepyx.ipynb
api/nsidc
LICENSE
```

```{include} ../README.md

```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
